==> apache-camel-quarkus-3.14.0-src.zip: camel-quarkus-3.14.0/integration-tests/hazelcast/src/test/java/org/apache/camel/quarkus/component/hazelcast/it/HazelcastInstanceTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.hazelcast.it;

import java.util.concurrent.TimeUnit;

import com.hazelcast.core.HazelcastInstance;
import io.quarkus.test.common.WithTestResource;
import io.quarkus.test.common.http.TestHTTPEndpoint;
import io.quarkus.test.junit.QuarkusTest;
import io.restassured.RestAssured;
import org.junit.jupiter.api.Test;

import static org.awaitility.Awaitility.await;

@QuarkusTest
@TestHTTPEndpoint(HazelcastInstanceResource.class)
@WithTestResource(HazelcastTestResource.class)
public class HazelcastInstanceTest {

    @Test
    public void testInstance() {
        HazelcastInstance newMember = HazelcastTestResource.addMemberToCluster();
        try {
            await().atMost(10L, TimeUnit.SECONDS)
                    .until(() -> RestAssured.get("/added").then().extract().body().asString().equals("1"));
        } finally {
            newMember.shutdown();

            await().atMost(10L, TimeUnit.SECONDS)
                    .until(() -> RestAssured.get("/deleted").then().extract().body().asString().equals("1"));
        }
    }
}

==> apache-camel-quarkus-3.30.0-src.zip: camel-quarkus-3.30.0/integration-tests/hazelcast/src/test/java/org/apache/camel/quarkus/component/hazelcast/it/HazelcastInstanceTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.hazelcast.it;

import java.util.concurrent.TimeUnit;

import com.hazelcast.core.HazelcastInstance;
import io.quarkus.test.common.QuarkusTestResource;
import io.quarkus.test.common.http.TestHTTPEndpoint;
import io.quarkus.test.junit.QuarkusTest;
import io.restassured.RestAssured;
import org.junit.jupiter.api.Test;

import static org.awaitility.Awaitility.await;

@QuarkusTest
@TestHTTPEndpoint(HazelcastInstanceResource.class)
@QuarkusTestResource(HazelcastTestResource.class)
public class HazelcastInstanceTest {

    @Test
    public void testInstance() {
        HazelcastInstance newMember = HazelcastTestResource.addMemberToCluster();
        try {
            await().atMost(10L, TimeUnit.SECONDS)
                    .until(() -> RestAssured.get("/added").then().extract().body().asString().equals("1"));
        } finally {
            newMember.shutdown();

            await().atMost(10L, TimeUnit.SECONDS)
                    .until(() -> RestAssured.get("/deleted").then().extract().body().asString().equals("1"));
        }
    }
}
